package tournament.test.configuration

import io.ktor.server.config.*
import org.slf4j.LoggerFactory
import software.amazon.awssdk.auth.credentials.AwsBasicCredentials
import software.amazon.awssdk.auth.credentials.StaticCredentialsProvider
import software.amazon.awssdk.enhanced.dynamodb.DynamoDbEnhancedAsyncClient
import software.amazon.awssdk.regions.Region
import software.amazon.awssdk.services.dynamodb.DynamoDbAsyncClient
import java.net.URI

private const val APPLICATION_YAML = "application.yaml"

class DynamoDbConfiguration {
    private val logger = LoggerFactory.getLogger(DynamoDbConfiguration::class.java)

    fun createDynamoDbClient(): DynamoDbAsyncClient {
        val url = ApplicationConfig(APPLICATION_YAML).property("ktor.database.dynamodbUrl").getString()
        val accessKey = ApplicationConfig(APPLICATION_YAML).property("ktor.database.accessKey").getString()
        val secretKey = ApplicationConfig(APPLICATION_YAML).property("ktor.database.secretKey").getString()
        return DynamoDbAsyncClient.builder()
            .endpointOverride(URI(url))
            .region(Region.US_EAST_1)
            .credentialsProvider(
                StaticCredentialsProvider.create(AwsBasicCredentials.create(accessKey, secretKey))
            )
            .build()

    }

    fun createDataSource(dynamoDbAsyncClient: DynamoDbAsyncClient): DynamoDbEnhancedAsyncClient {
        logger.info("Using dynamo-db config")
        return DynamoDbEnhancedAsyncClient.builder()
            .dynamoDbClient(dynamoDbAsyncClient)
            .build()
    }
}