package tournament.test.configuration

import tournament.test.player.repositories.PlayerRepository
import tournament.test.player.repositories.PlayerRepositoryImpl
import tournament.test.player.services.PlayerService
import tournament.test.player.services.PlayerServiceImpl
import io.ktor.server.application.*
import org.koin.dsl.module
import org.koin.ktor.plugin.Koin
import org.koin.logger.slf4jLogger

fun Application.configureKoin() {
    install(Koin) {
        slf4jLogger()
        modules(databaseModule, playerModule)
    }
}

val databaseModule = module {
    single { DynamoDbConfiguration().createDynamoDbClient() }
    single { DynamoDbConfiguration().createDataSource(get()) }
    single { DynamoDbMigrationService() }
}

val playerModule = module {
    single<PlayerRepository> { PlayerRepositoryImpl(get()) }
    single<PlayerService> { PlayerServiceImpl(get()) }
}
