package tournament.test.player.routes

import tournament.test.player.dtos.PlayerCreationDTO
import tournament.test.player.dtos.PlayerInfoDTO
import tournament.test.player.dtos.PlayerUpdateDTO
import tournament.test.player.services.PlayerService
import io.ktor.http.*
import io.ktor.server.application.*
import io.ktor.server.request.*
import io.ktor.server.response.*
import io.ktor.server.routing.*
import org.koin.ktor.ext.inject

private const val PLAYERS = "/players"

fun Routing.playerRoutes() {
    val playerService by inject<PlayerService>()
    route(PLAYERS) {
        get {
            val pseudo = call.request.queryParameters["pseudo"] ?: return@get call.respond(HttpStatusCode.BadRequest)
            call.respond<PlayerInfoDTO>(HttpStatusCode.OK, playerService.getPlayerInfoByPseudo(pseudo))
        }
        post {
            val request = call.receive<PlayerCreationDTO>()
            call.respond(HttpStatusCode.Created, playerService.createNewPlayer(request))
        }

        put {
            val request = call.receive<PlayerUpdateDTO>()
            call.respond(HttpStatusCode.OK, playerService.updatePlayer(request))
        }

        get("/ranking") {
            call.respond(HttpStatusCode.OK, playerService.getPlayersRanked())
        }

        delete {
            playerService.deleteAllPlayers()
            call.respond(HttpStatusCode.NoContent) // code de retours partout
        }

    }
}