import org.slf4j.LoggerFactory
import org.testcontainers.containers.localstack.LocalStackContainer
import org.testcontainers.utility.DockerImageName
import software.amazon.awssdk.auth.credentials.AwsBasicCredentials
import software.amazon.awssdk.auth.credentials.StaticCredentialsProvider
import software.amazon.awssdk.enhanced.dynamodb.DynamoDbEnhancedAsyncClient
import software.amazon.awssdk.regions.Region
import software.amazon.awssdk.services.dynamodb.DynamoDbAsyncClient


object TestDynamoDbConfiguration {
    private val logger = LoggerFactory.getLogger(TestDynamoDbConfiguration::class.java)

    val localStack: LocalStackContainer = LocalStackContainer(DockerImageName.parse("localstack/localstack:latest"))
        .withServices(LocalStackContainer.Service.DYNAMODB)

    init {
        logger.info("Starting LocalStack DynamoDB container for tests...")
        localStack.start()
    }

    fun createDynamoDbClient(): DynamoDbAsyncClient {
        val endpoint = localStack.getEndpointOverride(LocalStackContainer.Service.DYNAMODB)
        val credentials = AwsBasicCredentials.create(localStack.accessKey, localStack.secretKey)

        return DynamoDbAsyncClient.builder()
            .endpointOverride(endpoint)
            .credentialsProvider(StaticCredentialsProvider.create(credentials))
            .region(Region.US_EAST_1)
            .build()
    }

    fun createDataSource(dynamoDbAsyncClient: DynamoDbAsyncClient): DynamoDbEnhancedAsyncClient {
        logger.info("Using test dynamo-db config")
        return DynamoDbEnhancedAsyncClient.builder()
            .dynamoDbClient(dynamoDbAsyncClient)
            .build()
    }
}
